pub enum PartitionValue {
Null,
Int64(i64),
Float32(u32),
Float64(u64),
Bool(bool),
Binary(Vec<u8>),
Fixed(Vec<u8>),
}Expand description
A typed value used to compare partition keys.
Variants
Null
SQL-style NULL key component.
Int64(i64)
Signed 64-bit integer key component.
Float32(u32)
32-bit floating-point key component, stored by raw bits for total equality.
Float64(u64)
64-bit floating-point key component, stored by raw bits for total equality.
Bool(bool)
Boolean key component.
Binary(Vec<u8>)
Variable-length binary key component.
Fixed(Vec<u8>)
Fixed-length binary key component.