pub struct PartitionChunk {
pub key: PartitionKey,
pub batch: Arc<RecordBatch>,
pub rows: Range<usize>,
pub partition_ordinal: usize,
pub is_partition_start: bool,
pub is_partition_end: bool,
}Expand description
A contiguous chunk of rows belonging to one logical partition.
Fields
key: PartitionKeyPartition key for this chunk.
batch: Arc<RecordBatch>Shared record batch containing the rows.
rows: Range<usize>Row range in batch belonging to this chunk.
partition_ordinal: usizeZero-based ordinal of the logical partition in input order.
is_partition_start: boolTrue when this chunk starts a logical partition.
is_partition_end: boolTrue when this chunk ends a logical partition.
Implementations