pub enum ReadAtError {
Expired {
requested_epoch: u64,
readable_from_epoch: u64,
},
NotYetReadable {
requested_epoch: u64,
readable_through_epoch: u64,
},
Unavailable {
requested_epoch: u64,
reason: String,
},
}Expand description
Classified failure to open a fenced storage snapshot.
Variants
Expired
The requested epoch was compacted before a session could open.
Fields
NotYetReadable
The requested epoch has not been applied by the backend.
Fields
The backend has no admissible read-at implementation.