Module join

Module join 

Generic JOIN execution primitives.

This module contains type-independent JOIN control flow. Callers provide concrete row storage, predicate evaluation, key extraction, row construction, and null value construction.

Traits

RowLike
Minimal row interface required by generic JOIN row-combination helpers.

Functions

combine_rows
Combine left and right row values into a caller-owned output row.
hash_join
Execute a generic hash join for equi-joins.
nested_loop_join
Execute a generic nested-loop join.
pad_left
Combine a right row with left-side null padding.
pad_right
Combine a left row with right-side null padding.

Type Aliases

JoinPair
A generic joined row pair emitted by JOIN control-flow primitives.
JoinPairs
Generic joined row pairs emitted by JOIN control-flow primitives.