Module spill

Module spill 

Generic external-sort spill primitives.

Structs

SpillEntry
One decoded entry from a spill run.
SpillMergeIterator
K-way merge iterator over sorted spill run files.
SpillRunReader
Reader for one spill run file.

Functions

create_spill_file
Create a unique spill file in directory using prefix.
ensure_spill_dir
Ensure the spill directory exists.
spill_io_error
Convert a spill I/O failure into the stable core spill error variant.
spill_run
Write one sorted spill run to disk and clear the in-memory entries.