SpillRunReader

Struct SpillRunReader 

pub struct SpillRunReader<T, K> { /* private fields */ }
Reader for one spill run file.

Implementations

Source

impl<T, K> SpillRunReader<T, K>

pub fn open<DK, DR>( path: PathBuf, decode_key: DK, decode_row: DR, ) -> Result<Self>
where DK: Fn(&[u8]) -> Result<K> + 'static, DR: Fn(u64, &[u8]) -> Result<T> + 'static,

Open a spill run and configure decoders for key and row payloads.

pub fn next_entry(&mut self) -> Result<Option<SpillEntry<T, K>>>

Read the next spill entry, or None at end of run.