pub fn select_encoding(
logical_type: LogicalType,
hints: &EncodingHints,
) -> EncodingV2Expand description
Select optimal encoding based on data type and hints.
Returns the best encoding for the given data characteristics. Falls back to Plain if no better encoding is applicable.