Generic JOIN execution primitives.
This module contains type-independent JOIN control flow. Callers provide concrete row storage, predicate evaluation, key extraction, row construction, and null value construction.
Traits
- RowLike
- Minimal row interface required by generic JOIN row-combination helpers.
Functions
- combine_
rows - Combine left and right row values into a caller-owned output row.
- hash_
join - Execute a generic hash join for equi-joins.
- nested_
loop_ join - Execute a generic nested-loop join.
- pad_
left - Combine a right row with left-side null padding.
- pad_
right - Combine a left row with right-side null padding.