Generic external-sort spill primitives.
Structs
- Spill
Entry - One decoded entry from a spill run.
- Spill
Merge Iterator - K-way merge iterator over sorted spill run files.
- Spill
RunReader - Reader for one spill run file.
Functions
- create_
spill_ file - Create a unique spill file in
directoryusingprefix. - ensure_
spill_ dir - Ensure the spill directory exists.
- spill_
io_ error - Convert a spill I/O failure into the stable core spill error variant.
- spill_
run - Write one sorted spill run to disk and clear the in-memory entries.